@@ -21,19 +21,6 @@ limitations under the License.
 package test
 
 const (
-	// ServingNamespace is the default namespace for serving e2e tests
-	ServingNamespace = "serving-tests"
-
-	// AlternativeServingNamespace is a different namepace to run cross-
-	// namespace tests in.
-	AlternativeServingNamespace = "serving-tests-alt"
-
-	// ServingNamespaceforSecurityTesting is the namespace for security tests.
-	ServingNamespaceforSecurityTesting = "serving-tests-security"
-
-	// TLSNamespace is the namespace for serving tls tests
-	TLSNamespace = "tls"
-
 	// Environment propagation conformance test objects
 
 	// ConformanceConfigMap is the name of the configmap to propagate env variables from
@@ -48,9 +35,6 @@ const (
 	// EnvValue is the configmap/secret test value to match env variable with
 	EnvValue = "testValue"
 
-	// ContainerMemoryLimit is used in any test which needs a default memory resource limit
-	ContainerMemoryLimit = "350Mi"
-
 	// testAnnotation is an annotation attached to resources originating from tests.
 	testAnnotation = "knative-e2e-test"
 )
